@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14/Nef_2/include/CGAL/Extended_homogeneous.h $
+// $Id: Extended_homogeneous.h 97b5c37 %aI Andreas Fabri
 // SPDX-License-Identifier: GPL-3.0+
 // 
 //
@@ -28,7 +28,7 @@
 #include <CGAL/basic.h>
 #include <CGAL/Homogeneous.h> 
 #include <CGAL/Point_2.h> 
-#include <CGAL/Line_2_Line_2_intersection.h> 
+#include <CGAL/Intersections_2/Line_2_Line_2.h> 
 #include <CGAL/squared_distance_2.h> 
 #include <CGAL/number_utils.h>
 #include <CGAL/Nef_polynomial.h>
