@@ -12,8 +12,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 //
-// $URL$
-// $Id$
+// $URL: https://github.com/CGAL/cgal/blob/releases/CGAL-4.14/Triangulation/include/CGAL/IO/Triangulation_off_ostream.h $
+// $Id: Triangulation_off_ostream.h 21d53cd %aI Sebastien Loriot
 // SPDX-License-Identifier: LGPL-3.0+
 //
 // Author(s)     : Clement Jamin
@@ -118,88 +118,6 @@ input_point(std::istream & is, const Traits &traits, P & p)
 // TODO: replace these operator>> by an "input_point" function
 ///////////////////////////////////////////////////////////////
 
-// TODO: test if the stream is binary or text?
-template<typename K>
-std::istream &
-operator>>(std::istream &is, typename Wrap::Point_d<K> & p)
-{
-  typedef typename Wrap::Point_d<K> P;
-  typedef typename K::FT FT;
-  std::vector<FT> coords;
-
-  std::string line;
-  for(;;)
-  {
-    if (!std::getline(is, line))
-      return is;
-    if (line != "")
-      break;
-  }
-  std::stringstream line_sstr(line);
-  FT temp;
-  while (line_sstr >> temp)
-    coords.push_back(temp);
-
-  p = P(coords.begin(), coords.end());
-  return is;
-}
-
-// TODO: test if the stream is binary or text?
-template<typename K>
-std::istream &
-operator>>(std::istream &is, typename Wrap::Weighted_point_d<K> & wp)
-{
-  typedef typename Wrap::Point_d<K>           P;
-  typedef typename Wrap::Weighted_point_d<K>  WP;
-  typedef typename K::FT FT;
-
-  std::string line;
-  for(;;)
-  {
-    if (!std::getline(is, line))
-      return is;
-    if (line != "")
-      break;
-  }
-  std::stringstream line_sstr(line);
-  FT temp;
-  std::vector<FT> coords;
-  while (line_sstr >> temp)
-    coords.push_back(temp);
-  
-  typename std::vector<FT>::iterator last = coords.end() - 1;
-  P p = P(coords.begin(), last);
-  wp = WP(p, *last);
-
-  return is;
-}
-
-// TODO: test if the stream is binary or text?
-template<typename K>
-std::istream &
-operator>>(std::istream &is, typename Wrap::Vector_d<K> & v)
-{
-  typedef typename Wrap::Vector_d<K> V;
-  typedef typename K::FT FT;
-  std::vector<FT> coords;
-
-  std::string line;
-  for (;;)
-  {
-    if (!std::getline(is, line))
-      return is;
-    if (line != "")
-      break;
-  }
-  std::stringstream line_sstr(line);
-  FT temp;
-  while (line_sstr >> temp)
-    coords.push_back(temp);
-
-  v = V(coords.begin(), coords.end());
-  return is;
-}
-
 template < class GT, class TDS >
 std::ostream &
 export_triangulation_to_off(std::ostream & os,
